/*
    Grapple - A fully featured network layer with a simple interface
    Copyright (C) 2006 Michael Simms

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

    Michael Simms
    michael@linuxgamepublishing.com
*/

#ifndef GRAPPLE_NATTRAV_INTERNAL_H
#define GRAPPLE_NATTRAV_INTERNAL_H

#include "grapple_error.h"
#include "grapple_structs.h"
#include "grapple_nattrav_server.h"
#include "socket.h"
#include "dynstring.h"

typedef struct _nattrav_server_connection
{
  grapple_user userid;
  time_t connect_time;
  grapple_server server;
  grapple_thread_mutex *inuse;
  struct _nattrav_server_connection *next;
  struct _nattrav_server_connection *prev;
} nattrav_server_connection;

typedef struct _internal_nattrav_server_data
{
  grapple_nattrav_server nattravnum;
  int port;
  int port2;
  grapple_server server;
  grapple_server server2;
  char *ip;
  char *ip2;
  char *productname;
  char *productversion;
  grapple_thread_mutex *inuse;
  int threaddestroy;
  pthread_t thread;
  grapple_error last_error;
  struct _internal_nattrav_server_data *next;
  struct _internal_nattrav_server_data *prev;
} internal_nattrav_server_data;

extern internal_nattrav_server_data *internal_nattrav_get(grapple_nattrav_server);
extern void grapple_nattrav_server_error_set(internal_nattrav_server_data *,grapple_error);

typedef enum
  {
    GRAPPLE_NATTRAV_ADDRESS_REQUEST  = 1 ,
    GRAPPLE_NATTRAV_ADDRESS_RESPONSE = 2 ,
  } grapple_nattrav_messagetype_internal;

typedef enum
  {
    GRAPPLE_NATTRAV_STATE_OFF       = 0,
    GRAPPLE_NATTRAV_STATE_WAITING   = 1,
    GRAPPLE_NATTRAV_STATE_ON        = 2,
  } grapple_nattrav_state;

#endif
